<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>Tüm dosyalar  (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
</context>
<context>
    <name>NetUtils</name>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished">IP çakışması</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>Uçak Modu</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>Kablosuz iletişimi durdur</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Uçak kipinin etkinleştirilmesi kablosuz ağı, kişisel hotspot ve bluetooth&apos;u kapatır</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>Uygulama Vekil Sunucusu</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Proxy sunucularını ayarlayın</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vekil Sunucu Türü</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Adresi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Geçersiz IP adresi</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Geçersiz port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>İsteğe bağlı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Yapılandırıldıktan sonra Başlatıcı&apos;daki uygulama bağlamı menüsünde &quot;Vekil Sunucu Kullan&quot; seçeneğini işaretleyin.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>Çevirmeli ağ bağlantısı kurun</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Bağlantıyı kes</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Bağlan</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>PPPoE bağlantısı ekle</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Bu yapılandırmayı silmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>Ağ Ayrıntıları</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>Tüm ağ yapılandırmalarını görüntüle</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>Ayrıntılar kopyalandı</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Tümünü Seç</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>Ağ Algılama</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Kişisel</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Kişisel</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Bağlı Değil</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Kişisel Bağlantı Noktası</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>Ağı paylaşın</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>Erişim Noktam</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>Erişim Noktamı Düzenle</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>İsim (SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Güvenlik</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bant</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>Paylaşılan Ayarlar</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>Erişim Noktası Paylaşım Cihazı</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>Kişisel erişim noktasını kullanmak istiyorsanız, öncelikle Uçak Modu&apos;nu devre dışı bırakın ve ardından kablosuz ağ bağdaştırıcısını etkinleştirin.</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>Kişisel erişim noktasını kullanmak istiyorsanız, öncelikle &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Uçak Modunu&lt;/a&gt; devre dışı bırakın ve ardından kablosuz ağ bağdaştırıcısını etkinleştirin.</translation>
    </message>
    <message>
        <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Bu yapılandırmayı silmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>Sistem Vekil Sunucusu</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Proxy sunucularını ayarlayın</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vekil Sunucu Türü</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Yapılandırma Adresi</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Vekil Sunucusu</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Vekil Sunucusu</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP Vekil Sunucusu</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Vekil Sunucusu</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Yukarıdaki bilgisayar ve etki alanları için vekil sunucu yapılandırmaları yoksay</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>Bağlan, ekle, içe aktar</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Bağlantıyı kes</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Bağlan</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>VPN ekle</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN&apos;i içe aktar</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>İçe Aktarma Hatası</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Dosya hatası</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source>VPN Type</source>
        <translation>VPN Türü</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Bu yapılandırmayı silmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal et</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Dışarı aktar</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>%1 Network Properties</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Bağlan, ağ ayarlarını düzenle</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Önce ağ kablosunu takın</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Bağlantıyı kes</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Bağlan</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Ağ Bağlantısı Ekle</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Bağlan, ağ ayarlarını düzenle</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Bağlantıyı kes</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Bağlan</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>Diğer Ağlar</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>Kablosuz bir ağa bağlanmak istiyorsanız öncelikle Uçak Modunu devre dışı bırakın</translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Kablosuz bir ağa bağlanmak istiyorsanız öncelikle &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Uçak Modunu&lt;/a&gt; devre dışı bırakın</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Kablosuz bir ağa bağlanmak için erişim noktasını devre dışı bırakın</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Kablosuz bir ağa bağlanmak istiyorsanız önce &lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Erişim noktasını&lt;/a&gt; devre dışı bırakın</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation type="unfinished">Ağlarım</translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Tamamla</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Geçersiz IP adresi</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>Bağlı Değil</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Aygıtın MAC Adresi</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Kopyalanmış MAC Adresi</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU Değerini Özelleştir</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bant</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>İsim (SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Otomatik Bağlan</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Tamamla</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Devre Dışı</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Yöntem</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Sadece ilgili kaynaklarda uygulanır</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Adresi</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Geçersiz IP adresi</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Ağ Maskesi</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished">Geçersiz ağ geçidi</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>Devre Dışı</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Yoksay</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Tamamlandı</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Yöntem</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Sadece ilgili kaynaklarda uygulanır</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP Adresi</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Geçersiz IP adresi</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Ön Ek</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished">Geçersiz ağ geçidi</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE Kullan</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Durumsal MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD Veri Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Veri Küçültme Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP Üst Bilgi Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP Echo Paketleri Gönder</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servis</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>Güvenlik</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tünellenmiş TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Korumalı EAP</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Kişisel</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Kurumsal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Kişisel</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Kimlik Doğrulaması</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Kimlik</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Parola Ayarları</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Bu kullanıcı için parolayı kaydet</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Tüm kullanıcılar için parolayı kaydet</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Her zaman sor</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Anahtar</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Özel Parola</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Doğrulama</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Paylaşılan anahtar</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Açık sistem</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Özel Anahtar</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonim Kimlik</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Sağlama</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Devre Dışı</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonim</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Kimlik Doğrulandı</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>İkisi de</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC dosyası</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Sertifikası</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Kullanıcı Sertifikası</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP Sürümü</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Sürüm 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Sürüm 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>İç Kimlik Doğrulaması</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Tüm dosyalar  (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Geçersiz ağ geçidi</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Ağ Geçidi</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA Sertifikası</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Vekil Sunucu</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Cisco Güvenli Masaüstü Trojanına İzin Ver</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Betiği</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Kimlik Doğrulama Türü</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Özel Anahtar</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH İstemci</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Akıllı Kart</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Ön Paylaşımlı Anahtar</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Kullanıcı Sertifikası</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Anahtar Parolası için FSID kullan</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Sertifikalar (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Parolalı Sertifikalar (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statik Anahtar</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Parola Ayarları</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Kaydedildi</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Sor</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Zorunlu Değil</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Özel Parola</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Anahtar Yönünü Özelleştir</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Anahtar Yönü</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Uzak IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Yerel IP</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT Etki Alanı</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>İç IP Adresi İste</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>UDP Enkapsülasyonu Kullan</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP Sıkıştırmasını Kullan</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Özel Şifreleme Tekliflerini Etkinleştir</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Grup Adı</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Grup Parolası</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Karma Kimlik Doğrulaması Kullan</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA Dosyası</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE Kullan</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Güvenlik</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Tüm Kullanılabilenler (varsayılan)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 bit (daha az güvenli)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 bit (en güvenli)</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Durumsal MPPE</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 Kimlik Doğrulamasını Reddet</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>BSD Veri Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Veri Küçültme Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>TCP Üst Bilgi Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>İletişim Kuralı Alanı Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Adres/Denetim Sıkıştırması Yapma</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP Echo Paketleri Gönder</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec Kullanılsın</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Grup Kimliği</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>1. Aşama Algoritmaları</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>2. Aşama Algoritmaları</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Gelişmiş</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Ağ Geçidi Port Özelleştir</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Ağ Geçidi Port</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Yeniden Görüşme Sıklığını Özelleştir</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Yeniden Görüşme Sıklığı</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO Veri Sıkıştırması Kullan</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP Bağlantısı Kullan</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP Aygıtı Kullan</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Tünel MTU Değerini Özelleştir</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP Parça Boyutunu Özelleştir</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP Parça Boyutu</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Tünel TCP MSS&apos;yi Kısıtla</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Uzak Ana Bilgisayarları Rastgele Ayarla</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Etki Alanı</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Yayınlayan</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (varsayılan)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versiyon</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Şifreleme</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Güvenli (varsayılan)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Zayıf</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT Geçiş Kipi</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>Kullanılabildiğinde NAT-T (varsayılan)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Her Zaman NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Devre Dışı</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Grubu</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>1. DH Grubu</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>2. DH Grubu (varsayılan)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>5. DH Grubu</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>İletme Gizliliği</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Sunucu (varsayılan)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>2. DH Grubu</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Yerel Port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Kayıp Eş Algılamayı Devre Dışı Bırak</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>VPN Güvenliği</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Şifre</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Kimlik Doğrulama</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Vekil Sunucu</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Vekil Sunucu Türü</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Sunucu IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Başarısız Olduğunda Sürekli Dene</translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS Kimlik Doğrulaması</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Konu Eşleşmesi</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Uzak Sertifika Türü</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>İstemci</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Sunucu</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Anahtar Dosyası</translation>
    </message>
    <message>
        <source>MTU (1280-9000)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>İsteğe bağlı</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>Kimlik doğrulama gerekli</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Gerekli</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Kablosuz bir ağa bağlanmak istiyorsanız öncelikle &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Uçak Modunu&lt;/a&gt; devre dışı bırakın</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>IP çakışması</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Kablolu Bağlantı %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE Bğlantısı %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Bağlanıyor &quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; bağlandı</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; bağlantısı kesildi</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>&quot;%1&quot; bağlantısı kurulamıyor, lütfen yönlendiricinizi veya ağ kablonuzu kontrol edin.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>&quot;%1&quot; bağlantısı kurulamıyor, lütfen kablosuz yönlendiriciye daha yakın olun</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Bağlantı başarısız oldu, &quot;%1&quot;e bağlanılamadı, yanlış parola</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>&quot;%1&quot; &apos;e bağlanmak için parola gerekli</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>&quot;%1&quot;  802.11 WLAN ağı bulunamadı</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>&quot;%1&quot;e bağlanmak için lütfen oturum açtıktan sonra kimlik doğrulama bilgilerinizi ayarlayın</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Sistem Vekil Sunucusu</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>VPN yapılandırması bağlı değil veya bağlanamadı. Lütfen inceleme için &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;kontrol merkezine gidin.&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Kablolu Ağ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Kablosuz Ağ</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Gizli ağa bağlan</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Ağlarım</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Diğer Ağlar</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
</context>
<context>
    <name>networkMain</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Related Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
